@@ -10,8 +10,8 @@ pub use errors::*;
 
 #[derive(Debug, serde::Deserialize)]
 pub struct Pager<T> {
-    total: usize,
-    data: Vec<T>,
+    pub total: usize,
+    pub data: Vec<T>,
 }
 
 #[derive(Clone)]
@@ -183,18 +183,22 @@ impl Api {
         Self::request(reqwest::Method::POST, config, request).await
     }
 
-    pub(crate) async fn delete<T: for<'de> serde::Deserialize<'de>, P: serde::Serialize>(
+    pub(crate) async fn delete<P: serde::Serialize>(
         config: &Config,
         request: Request<P>,
-    ) -> crate::Result<T> {
-        Self::request(reqwest::Method::DELETE, config, request).await
+    ) -> crate::Result<()> {
+        Self::request::<data::Empty, _>(reqwest::Method::DELETE, config, request)
+            .await?
+            .into()
     }
 
-    pub(crate) async fn put<T: for<'de> serde::Deserialize<'de>, P: serde::Serialize>(
+    pub(crate) async fn put<P: serde::Serialize>(
         config: &Config,
         request: Request<P>,
-    ) -> crate::Result<T> {
-        Self::request(reqwest::Method::PUT, config, request).await
+    ) -> crate::Result<()> {
+        Self::request::<data::Empty, _>(reqwest::Method::PUT, config, request)
+            .await?
+            .into()
     }
 
     async fn request<T: for<'de> serde::Deserialize<'de>, P: serde::Serialize>(
